@@ -2,10 +2,12 @@
 
 from __future__ import annotations
 
-from typing import Optional, Union, List
-from uuid import UUID
-from pathlib import Path
 from ipaddress import IPv4Address, IPv6Address, IPv4Network, IPv6Network
+from typing import Optional, Union, List
+from pathlib import Path
+from uuid import UUID
+
+import yaml
 
 from .base import TimewebCloudBase
 from .types import (
@@ -34,6 +36,43 @@ from .types import (
 class TimewebCloud(TimewebCloudBase):
     """Timeweb Cloud API client class."""
 
+    # -----------------------------------------------------------------------
+    # Apps
+
+    def get_apps(self):
+        """Return Timeweb Cloud apps list."""
+        return self._request("GET", f"{self.api_url}/apps")
+
+    def create_app(self, yaml_config_path: str):
+        """Create Timeweb Cloud app."""
+
+        with open(yaml_config_path, "r", encoding="utf-8") as f:
+            payload = yaml.safe_load(f)
+        payload = payload["app"]
+        return self._request("POST", f"{self.api_url}/apps", json=payload)
+
+    def get_app(self, app_id: int):
+        """Return Timeweb Cloud app."""
+        return self._request("GET", f"{self.api_url}/apps/{app_id}")
+
+    def get_vcs_providers(self):
+        """Return Timeweb Cloud vcs providers."""
+        return self._request("GET", f"{self.api_url}/vcs-provider")
+
+    def get_repositories(self, vcs_provider_id: str):
+        """Return Timeweb Cloud user vcs repositories."""
+        return self._request(
+            "GET", f"{self.api_url}/vcs-provider/{vcs_provider_id}"
+        )
+
+    def get_apps_tarifs(self):
+        """Return Timeweb Cloud Apps tarifs"""
+        return self._request("GET", f"{self.api_url}/presets/apps")
+
+    def delete_app(self, app_id: int):
+        """Delete Timeweb Cloud app."""
+        return self._request("DELETE", f"{self.api_url}/apps/{app_id}")
+
     # -----------------------------------------------------------------------
     # Account
 
